@@ -15,11 +15,11 @@ except ModuleNotFoundError as e:
 
 class SpacyFactor(object):
     def __init__(
-        self,
-        issue_type: str,
-        simple_description: str,
-        description: Optional[str] = None,
-        debug=False,
+            self,
+            issue_type: str,
+            simple_description: str,
+            description: Optional[str] = None,
+            debug=False,
     ):
         self.issue_type = issue_type
         self.simple_description = simple_description
@@ -56,7 +56,7 @@ class SpacyFactor(object):
                     # len condition is to exclude capitalization caused by "I"
                     suggestions = [s.upper() for s in suggestions]
                 elif (len(words[0]) > 1 and words[0][0].isupper()) or (
-                    is_sent_start and len(span[0]) == 1
+                        is_sent_start and len(span[0]) == 1
                 ):
                     # title case - first letter check & conversion due to contractions
                     for i, s in enumerate(suggestions):
@@ -73,7 +73,7 @@ class SpacyFactor(object):
         return suggestions
 
     def __call__(
-        self, spacy_span: Span, meta_subcategory=None, describer=None, cased=True
+            self, spacy_span: Span, meta_subcategory=None, describer=None, cased=True
     ):
         """
         convenient wrapper around make_issue if you are using spaCy
@@ -118,13 +118,14 @@ class SpacyFactor(object):
         meta_dict = (
             spacy_span._.meta_dict if spacy_span.has_extension("meta_dict") else {}
         )
+        visible = (spacy_span._.visible if spacy_span.has_extension("visible") else True)
         # SIMPLE DESCRIPTION IS DIFFERENT, since it is set when initialized
         # so we need to check that the span doesn't just have an empty value
         simple_description = (
             spacy_span._.simple_description
             if (
-                spacy_span.has_extension("simple_description")
-                and spacy_span._.simple_description != ""
+                    spacy_span.has_extension("simple_description")
+                    and spacy_span._.simple_description != ""
             )
             else self.simple_description
         )
@@ -163,5 +164,6 @@ class SpacyFactor(object):
             metaDict=meta_dict,
             accept_all_changes=accept_all_changes,
             debug=self.debug,
-            segment=spacy_span.doc.text
+            segment=spacy_span.doc.text,
+            visible=visible
         )
